pub struct BacktrackingLineSearch<V: Vector> {
pub tau: V::T,
pub c: V::T,
pub steptol: V::T,
pub max_iter: usize,
pub n_iters: usize,
/* private fields */
}Expand description
Backtracking line search implementation, derived from backtracking line search algorithm in Sundials IDA solver (https://github.com/LLNL/sundials/blob/main/src/ida/ida_ic.c#L480)
Parameters:
- tau: step size reduction factor (0 < tau < 1), default 0.5
- c: Armijo condition constant (0 < c < 1), default 1e-4
- steptol: minimum step size, default eps^(2/3)
- max_iter: maximum number of line search iterations, default 100
- n_iters: number of line search iterations performed during last call
Fields
tau: V::Tc: V::Tsteptol: V::Tmax_iter: usizen_iters: usizeTrait Implementations
Sourceimpl<V: Vector> Default for BacktrackingLineSearch<V>
impl<V: Vector> Default for BacktrackingLineSearch<V>
Sourceimpl<V: Vector> LineSearch<V> for BacktrackingLineSearch<V>
impl<V: Vector> LineSearch<V> for BacktrackingLineSearch<V>
Sourcefn take_optimal_step(
&mut self,
x: &mut V,
delta: &mut V,
error_y: &V,
fun: &impl Fn(&V, &mut V),
linear_solver: &impl Fn(&mut V) -> Result<(), DiffsolError>,
convergence: &mut Convergence<'_, V>,
) -> Result<ConvergenceStatus, DiffsolError>
fn take_optimal_step( &mut self, x: &mut V, delta: &mut V, error_y: &V, fun: &impl Fn(&V, &mut V), linear_solver: &impl Fn(&mut V) -> Result<(), DiffsolError>, convergence: &mut Convergence<'_, V>, ) -> Result<ConvergenceStatus, DiffsolError>
Take the optimal step for the current iteration Read more