pub struct RootFinder<V: Vector> { /* private fields */ }Implementations
Sourceimpl<V: Vector> RootFinder<V>
impl<V: Vector> RootFinder<V>
pub fn new(nroots: usize, nstates: usize, ctx: V::C) -> Self
Sourcepub fn init(&self, root_fn: &impl NonLinearOp<V = V, T = V::T>, y: &V, t: V::T)
pub fn init(&self, root_fn: &impl NonLinearOp<V = V, T = V::T>, y: &V, t: V::T)
Set the lower boundary of the root search. This function should be called first after Self::new
Sourcepub fn check_root(
&self,
interpolate_inplace: &impl Fn(V::T, &mut V) -> Result<(), DiffsolError>,
root_fn: &impl NonLinearOp<V = V, T = V::T>,
y: &V,
t: V::T,
) -> Option<V::T>
pub fn check_root( &self, interpolate_inplace: &impl Fn(V::T, &mut V) -> Result<(), DiffsolError>, root_fn: &impl NonLinearOp<V = V, T = V::T>, y: &V, t: V::T, ) -> Option<V::T>
Set the upper boundary of the root search and checks for a zero crossing. If a zero crossing is found, the index of the crossing is returned
This function assumes that g0 and t0 have already beeen set via Self::init or previous iterations of Self::check_root
We find the root of a function using the method proposed by Sundials docs