Module ode_equations

Module ode_equations 

ODE equations and traits.

This module defines the OdeEquations trait and specialized variants:

It also provides implementations:

All the test equations used in Diffsol’s test suite are also provided here.

Modules

adjoint_equations
diffsl
sens_equations
test_models

Structs

NoAug
OdeEquationsStatistics
OdeSolverEquations
This struct implements the ODE equation trait OdeEquations for a given right-hand side op, mass op, optional root op, and initial condition function.

Traits

AugmentedOdeEquations
AugmentedOdeEquationsImplicit
OdeEquations
this is the trait that defines the ODE equations of the form
OdeEquationsAdjoint
OdeEquationsImplicit
OdeEquationsImplicitAdjoint
OdeEquationsImplicitSens
OdeEquationsRef
this is the reference trait that defines the ODE equations of the form, this is used to define the ODE equations for a given lifetime. See OdeEquations for the main trait that defines the ODE equations.
OdeEquationsStoch