AdjointRhs

Struct AdjointRhs 

pub struct AdjointRhs<'a, Eqn, Method>
where Eqn: OdeEquations, Method: OdeSolverMethod<'a, Eqn>,
{ /* private fields */ }
Right-hand side of the adjoint equations is:

F(λ, x, t) = -f^T_x(x, t) λ - g^T_x(x,t)

f_x is the partial derivative of the right-hand side with respect to the state vector. g_x is the partial derivative of the functional g with respect to the state vector.

We need the current state x(t), which is obtained from the checkpointed forward solve at the current time step.

Implementations

Source

impl<'a, Eqn, Method> AdjointRhs<'a, Eqn, Method>
where Eqn: OdeEquations, Method: OdeSolverMethod<'a, Eqn>,

pub fn new( eqn: &'a Eqn, context: Rc<RefCell<AdjointContext<'a, Eqn, Method>>>, with_out: bool, ) -> Self