OdeSolverEquations

Struct OdeSolverEquations 

pub struct OdeSolverEquations<M, Rhs, Init, Mass, Root, Out, Reset = UnitCallable<M>>
where M: Matrix,
{ /* private fields */ }
This struct implements the ODE equation trait OdeEquations for a given right-hand side op, mass op, optional root op, and initial condition function.

While the crate::OdeBuilder struct is the easiest way to define an ODE problem, occasionally a user might want to use their own structs that define the equations instead of closures or the DiffSL languave, and this can be done using OdeSolverEquations.

The main traits that you need to implement are the crate::Op and NonLinearOp trait, which define a nonlinear operator or function F that maps an input vector x to an output vector y, (i.e. y = F(x)). Once you have implemented this trait, you can then pass an instance of your struct to the rhs argument of the Self::new method. Once you have created an instance of OdeSolverEquations, you can then use crate::OdeBuilder::build_from_eqn to create a problem.

Implementations

Source

impl<M, Rhs, Init, Mass, Root, Out, Reset> OdeSolverEquations<M, Rhs, Init, Mass, Root, Out, Reset>
where M: Matrix,

pub fn new( rhs: Rhs, init: Init, mass: Option<Mass>, root: Option<Root>, out: Option<Out>, reset: Option<Reset>, p: M::V, ) -> Self