ExplicitRk

Struct ExplicitRk 

pub struct ExplicitRk<'a, Eqn, M = <<Eqn as Op>::V as DefaultDenseMatrix>::M, AugmentedEqn = NoAug<Eqn>>
where Eqn: OdeEquations, M: DenseMatrix<V = Eqn::V, T = Eqn::T>, Eqn::V: DefaultDenseMatrix<T = Eqn::T, C = Eqn::C>, AugmentedEqn: AugmentedOdeEquations<Eqn>,
{ /* private fields */ }
An explicit Runge-Kutta method.

The particular method is defined by the Tableau used to create the solver. If the beta matrix of the Tableau is present this is used for interpolation, otherwise hermite interpolation is used.

Restrictions:

  • The upper triangular and diagonal parts of the a matrix must be zero (i.e. explicit).
  • The last row of the a matrix must be the same as the b vector, and the last element of the c vector must be 1 (i.e. a stiffly accurate method)

Implementations

Source

impl<'a, Eqn, M, AugmentedEqn> ExplicitRk<'a, Eqn, M, AugmentedEqn>
where Eqn: OdeEquations, M: DenseMatrix<V = Eqn::V, T = Eqn::T, C = Eqn::C>, AugmentedEqn: AugmentedOdeEquations<Eqn>, Eqn::V: DefaultDenseMatrix<T = Eqn::T, C = Eqn::C>,

pub fn new( problem: &'a OdeSolverProblem<Eqn>, state: RkState<Eqn::V>, tableau: Tableau<M>, ) -> Result<Self, DiffsolError>

pub fn new_augmented( problem: &'a OdeSolverProblem<Eqn>, state: RkState<Eqn::V>, tableau: Tableau<M>, augmented_eqn: AugmentedEqn, ) -> Result<Self, DiffsolError>

pub fn get_statistics(&self) -> &BdfStatistics