OdeSolverOptions

Struct OdeSolverOptions 

pub struct OdeSolverOptions<T: Scalar> {
Show 13 fields pub max_nonlinear_solver_iterations: usize, pub max_error_test_failures: usize, pub max_nonlinear_solver_failures: usize, pub nonlinear_solver_tolerance: T, pub min_timestep: T, pub max_timestep_growth: Option<T>, pub min_timestep_growth: Option<T>, pub max_timestep_shrink: Option<T>, pub min_timestep_shrink: Option<T>, pub update_jacobian_after_steps: usize, pub update_rhs_jacobian_after_steps: usize, pub threshold_to_update_jacobian: T, pub threshold_to_update_rhs_jacobian: T,
}
Options for the ODE solver. These options control various aspects of the solver’s behavior. Some options may not be applicable to all solver methods (e.g. implicit vs explicit methods).

Fields

max_nonlinear_solver_iterations: usize

maximum number of nonlinear solver iterations per solve (default: 10)

max_error_test_failures: usize

maximum number of error test failures before aborting the solve and returning an error (default: 40)

max_nonlinear_solver_failures: usize

maximum number of nonlinear solver failures before aborting the solve and returning an error (default: 50)

nonlinear_solver_tolerance: T

nonlinear solver convergence tolerance (default: 0.2)

min_timestep: T

minimum allowed timestep size (default: 1e-13)

max_timestep_growth: Option<T>

optional maximum timestep growth factor (solver-specific default when None)

min_timestep_growth: Option<T>

optional minimum timestep growth factor (solver-specific default when None)

max_timestep_shrink: Option<T>

optional maximum timestep shrink factor (solver-specific default when None)

min_timestep_shrink: Option<T>

optional minimum timestep shrink factor (solver-specific default when None)

update_jacobian_after_steps: usize

maximum number of steps after which to update the Jacobian (default: 20). This only requires an additional linear solver setup, not evaluation of the full Jacobian.

update_rhs_jacobian_after_steps: usize

maximum number of steps after which to update the RHS Jacobian (default: 50). This evaluates the full Jacobian of the RHS function and requires an additional linear solver setup.

threshold_to_update_jacobian: T

threshold on the change in timestep size |dt_new / dt_old - 1| to trigger a Jacobian update (default: 0.3)

threshold_to_update_rhs_jacobian: T

threshold on the change in timestep size |dt_new / dt_old - 1| to trigger a RHS Jacobian update (default: 0.2)