pub struct FaerVec<T: FaerScalar> { /* private fields */ }Trait Implementations
Sourceimpl<T: Scalar + FaerScalar> Add<&FaerVec<T>> for FaerVecRef<'_, T>
impl<T: Scalar + FaerScalar> Add<&FaerVec<T>> for FaerVecRef<'_, T>
Sourceimpl<T: Scalar + FaerScalar> Add<&FaerVecRef<'_, T>> for &FaerVec<T>
impl<T: Scalar + FaerScalar> Add<&FaerVecRef<'_, T>> for &FaerVec<T>
Sourceimpl<T: Scalar + FaerScalar> Add<&FaerVecRef<'_, T>> for FaerVec<T>
impl<T: Scalar + FaerScalar> Add<&FaerVecRef<'_, T>> for FaerVec<T>
Sourceimpl<T: Scalar + FaerScalar> Add<FaerVec<T>> for FaerVecRef<'_, T>
impl<T: Scalar + FaerScalar> Add<FaerVec<T>> for FaerVecRef<'_, T>
Sourceimpl<T: Scalar + FaerScalar> Add<FaerVecRef<'_, T>> for &FaerVec<T>
impl<T: Scalar + FaerScalar> Add<FaerVecRef<'_, T>> for &FaerVec<T>
Sourceimpl<T: Scalar + FaerScalar> Add<FaerVecRef<'_, T>> for FaerVec<T>
impl<T: Scalar + FaerScalar> Add<FaerVecRef<'_, T>> for FaerVec<T>
Sourceimpl<T: Scalar + FaerScalar> AddAssign<&FaerVec<T>> for FaerVec<T>
impl<T: Scalar + FaerScalar> AddAssign<&FaerVec<T>> for FaerVec<T>
Sourcefn add_assign(&mut self, rhs: &FaerVec<T>)
fn add_assign(&mut self, rhs: &FaerVec<T>)
Performs the
+= operation. Read moreSourceimpl<T: Scalar + FaerScalar> AddAssign<&FaerVec<T>> for FaerVecMut<'_, T>
impl<T: Scalar + FaerScalar> AddAssign<&FaerVec<T>> for FaerVecMut<'_, T>
Sourcefn add_assign(&mut self, rhs: &FaerVec<T>)
fn add_assign(&mut self, rhs: &FaerVec<T>)
Performs the
+= operation. Read moreSourceimpl<T: Scalar + FaerScalar> AddAssign<&FaerVecRef<'_, T>> for FaerVec<T>
impl<T: Scalar + FaerScalar> AddAssign<&FaerVecRef<'_, T>> for FaerVec<T>
Sourcefn add_assign(&mut self, rhs: &FaerVecRef<'_, T>)
fn add_assign(&mut self, rhs: &FaerVecRef<'_, T>)
Performs the
+= operation. Read moreSourceimpl<T: Scalar + FaerScalar> AddAssign<FaerVec<T>> for FaerVecMut<'_, T>
impl<T: Scalar + FaerScalar> AddAssign<FaerVec<T>> for FaerVecMut<'_, T>
Sourcefn add_assign(&mut self, rhs: FaerVec<T>)
fn add_assign(&mut self, rhs: FaerVec<T>)
Performs the
+= operation. Read moreSourceimpl<T: Scalar + FaerScalar> AddAssign<FaerVecRef<'_, T>> for FaerVec<T>
impl<T: Scalar + FaerScalar> AddAssign<FaerVecRef<'_, T>> for FaerVec<T>
Sourcefn add_assign(&mut self, rhs: FaerVecRef<'_, T>)
fn add_assign(&mut self, rhs: FaerVecRef<'_, T>)
Performs the
+= operation. Read moreSourceimpl<T: Scalar + FaerScalar> AddAssign for FaerVec<T>
impl<T: Scalar + FaerScalar> AddAssign for FaerVec<T>
Sourcefn add_assign(&mut self, rhs: FaerVec<T>)
fn add_assign(&mut self, rhs: FaerVec<T>)
Performs the
+= operation. Read moreSourceimpl<T: FaerScalar> DefaultDenseMatrix for FaerVec<T>
impl<T: FaerScalar> DefaultDenseMatrix for FaerVec<T>
Sourceimpl<'a, T: FaerScalar> MulAssign<Scale<T>> for FaerVec<T>
impl<'a, T: FaerScalar> MulAssign<Scale<T>> for FaerVec<T>
Sourcefn mul_assign(&mut self, rhs: Scale<T>)
fn mul_assign(&mut self, rhs: Scale<T>)
Performs the
*= operation. Read moreSourceimpl<T: Scalar + FaerScalar> Sub<&FaerVec<T>> for FaerVecRef<'_, T>
impl<T: Scalar + FaerScalar> Sub<&FaerVec<T>> for FaerVecRef<'_, T>
Sourceimpl<T: Scalar + FaerScalar> Sub<&FaerVecRef<'_, T>> for &FaerVec<T>
impl<T: Scalar + FaerScalar> Sub<&FaerVecRef<'_, T>> for &FaerVec<T>
Sourceimpl<T: Scalar + FaerScalar> Sub<&FaerVecRef<'_, T>> for FaerVec<T>
impl<T: Scalar + FaerScalar> Sub<&FaerVecRef<'_, T>> for FaerVec<T>
Sourceimpl<T: Scalar + FaerScalar> Sub<FaerVec<T>> for FaerVecRef<'_, T>
impl<T: Scalar + FaerScalar> Sub<FaerVec<T>> for FaerVecRef<'_, T>
Sourceimpl<T: Scalar + FaerScalar> Sub<FaerVecRef<'_, T>> for &FaerVec<T>
impl<T: Scalar + FaerScalar> Sub<FaerVecRef<'_, T>> for &FaerVec<T>
Sourceimpl<T: Scalar + FaerScalar> Sub<FaerVecRef<'_, T>> for FaerVec<T>
impl<T: Scalar + FaerScalar> Sub<FaerVecRef<'_, T>> for FaerVec<T>
Sourceimpl<T: Scalar + FaerScalar> SubAssign<&FaerVec<T>> for FaerVec<T>
impl<T: Scalar + FaerScalar> SubAssign<&FaerVec<T>> for FaerVec<T>
Sourcefn sub_assign(&mut self, rhs: &FaerVec<T>)
fn sub_assign(&mut self, rhs: &FaerVec<T>)
Performs the
-= operation. Read moreSourceimpl<T: Scalar + FaerScalar> SubAssign<&FaerVec<T>> for FaerVecMut<'_, T>
impl<T: Scalar + FaerScalar> SubAssign<&FaerVec<T>> for FaerVecMut<'_, T>
Sourcefn sub_assign(&mut self, rhs: &FaerVec<T>)
fn sub_assign(&mut self, rhs: &FaerVec<T>)
Performs the
-= operation. Read moreSourceimpl<T: Scalar + FaerScalar> SubAssign<&FaerVecRef<'_, T>> for FaerVec<T>
impl<T: Scalar + FaerScalar> SubAssign<&FaerVecRef<'_, T>> for FaerVec<T>
Sourcefn sub_assign(&mut self, rhs: &FaerVecRef<'_, T>)
fn sub_assign(&mut self, rhs: &FaerVecRef<'_, T>)
Performs the
-= operation. Read moreSourceimpl<T: Scalar + FaerScalar> SubAssign<FaerVec<T>> for FaerVecMut<'_, T>
impl<T: Scalar + FaerScalar> SubAssign<FaerVec<T>> for FaerVecMut<'_, T>
Sourcefn sub_assign(&mut self, rhs: FaerVec<T>)
fn sub_assign(&mut self, rhs: FaerVec<T>)
Performs the
-= operation. Read moreSourceimpl<T: Scalar + FaerScalar> SubAssign<FaerVecRef<'_, T>> for FaerVec<T>
impl<T: Scalar + FaerScalar> SubAssign<FaerVecRef<'_, T>> for FaerVec<T>
Sourcefn sub_assign(&mut self, rhs: FaerVecRef<'_, T>)
fn sub_assign(&mut self, rhs: FaerVecRef<'_, T>)
Performs the
-= operation. Read moreSourceimpl<T: Scalar + FaerScalar> SubAssign for FaerVec<T>
impl<T: Scalar + FaerScalar> SubAssign for FaerVec<T>
Sourcefn sub_assign(&mut self, rhs: FaerVec<T>)
fn sub_assign(&mut self, rhs: FaerVec<T>)
Performs the
-= operation. Read moreSourceimpl<T: FaerScalar> Vector for FaerVec<T>
impl<T: FaerScalar> Vector for FaerVec<T>
type View<'a> = FaerVecRef<'a, T>
type ViewMut<'a> = FaerVecMut<'a, T>
type Index = FaerVecIndex
Sourcefn context(&self) -> &Self::C
fn context(&self) -> &Self::C
Get the context associated with this vector (for device placement, threading, etc.).
Sourcefn inner_mut(&mut self) -> &mut Self::Inner
fn inner_mut(&mut self) -> &mut Self::Inner
Get a mutable reference to the inner representation of the vector.
Sourcefn set_index(&mut self, index: IndexType, value: Self::T)
fn set_index(&mut self, index: IndexType, value: Self::T)
Set the value at the specified index to
value.Sourcefn squared_norm(&self, y: &Self, atol: &Self, rtol: Self::T) -> Self::T
fn squared_norm(&self, y: &Self, atol: &Self, rtol: Self::T) -> Self::T
Compute the squared weighted norm for error control: $\sum_i (x_i / (|y_i| \cdot \text{rtol} + \text{atol}_i))^2$ Read more
Sourcefn as_view_mut(&mut self) -> Self::ViewMut<'_>
fn as_view_mut(&mut self) -> Self::ViewMut<'_>
Create a mutable view of this vector.
Sourcefn copy_from_view(&mut self, other: &Self::View<'_>)
fn copy_from_view(&mut self, other: &Self::View<'_>)
Copy all values from a vector view into this vector.
Sourcefn from_element(nstates: usize, value: Self::T, ctx: Self::C) -> Self
fn from_element(nstates: usize, value: Self::T, ctx: Self::C) -> Self
Create a vector of length
nstates with all elements initialized to value.Sourcefn from_slice(slice: &[Self::T], ctx: Self::C) -> Self
fn from_slice(slice: &[Self::T], ctx: Self::C) -> Self
Create a vector from a slice.
Sourcefn clone_as_vec(&self) -> Vec<Self::T>
fn clone_as_vec(&self) -> Vec<Self::T>
Clone this vector as a Rust
Vec.Sourcefn zeros(nstates: usize, ctx: Self::C) -> Self
fn zeros(nstates: usize, ctx: Self::C) -> Self
Create a vector of length
nstates with all elements set to zero.Sourcefn axpy(&mut self, alpha: Self::T, x: &Self, beta: Self::T)
fn axpy(&mut self, alpha: Self::T, x: &Self, beta: Self::T)
Compute the AXPY operation: self = alpha * x + beta * self
Sourcefn axpy_v(&mut self, alpha: Self::T, x: &Self::View<'_>, beta: Self::T)
fn axpy_v(&mut self, alpha: Self::T, x: &Self::View<'_>, beta: Self::T)
Compute the AXPY operation with a vector view: self = alpha * x + beta * self
Sourcefn component_mul_assign(&mut self, other: &Self)
fn component_mul_assign(&mut self, other: &Self)
Element-wise multiplication: self_i *= other_i
Sourcefn component_div_assign(&mut self, other: &Self)
fn component_div_assign(&mut self, other: &Self)
Element-wise division: self_i /= other_i
Sourcefn root_finding(&self, g1: &Self) -> (bool, Self::T, i32)
fn root_finding(&self, g1: &Self) -> (bool, Self::T, i32)
Detect roots (zero crossings) between this vector (as g0) and another vector (g1). Read more
Sourcefn assign_at_indices(&mut self, indices: &Self::Index, value: Self::T)
fn assign_at_indices(&mut self, indices: &Self::Index, value: Self::T)
Assign
value to all elements at the specified indices.Sourcefn copy_from_indices(&mut self, other: &Self, indices: &Self::Index)
fn copy_from_indices(&mut self, other: &Self, indices: &Self::Index)
Copy values from
other at the specified indices: self[indices[i]] = other[indices[i]]Sourcefn gather(&mut self, other: &Self, indices: &Self::Index)
fn gather(&mut self, other: &Self, indices: &Self::Index)
Gather values from
other at indices: self[i] = other[indices[i]]Sourcefn scatter(&self, indices: &Self::Index, other: &mut Self)
fn scatter(&self, indices: &Self::Index, other: &mut Self)
Scatter values to
other at indices: other[indices[i]] = self[i]Sourcefn assert_eq_st(&self, other: &Self, tol: Self::T)
fn assert_eq_st(&self, other: &Self, tol: Self::T)
Assert that this vector equals
other within a scalar tolerance tol.Sourcefn assert_eq_norm(
&self,
other: &Self,
atol: &Self,
rtol: Self::T,
factor: Self::T,
)
fn assert_eq_norm( &self, other: &Self, atol: &Self, rtol: Self::T, factor: Self::T, )
Assert that this vector equals
other using a weighted norm (same as used by ODE solvers). Read moreSourcefn assert_eq(&self, other: &Self, tol: &Self)
fn assert_eq(&self, other: &Self, tol: &Self)
Assert that this vector equals
other using a vector of per-element tolerances.fn assert_eq_vec(s: Vec<Self::T>, other: Vec<Self::T>, tol: Vec<Self::T>)
Sourceimpl<T: Scalar + FaerScalar> VectorCommon for FaerVec<T>
impl<T: Scalar + FaerScalar> VectorCommon for FaerVec<T>
Sourceimpl<T: FaerScalar> VectorHost for FaerVec<T>
impl<T: FaerScalar> VectorHost for FaerVec<T>
impl<T: FaerScalar> StructuralPartialEq for FaerVec<T>