VectorRef

Trait VectorRef 

pub trait VectorRef<V: Vector>:
    VectorOpsByValue<V, V>
    + for<'a> VectorOpsByValue<&'a V, V>
    + for<'a> VectorOpsByValue<V::View<'a>, V>
    + for<'a, 'b> VectorOpsByValue<&'a V::View<'b>, V>
    + Mul<Scale<V::T>, Output = V> { }
Operations on a reference to a vector, supporting addition, subtraction, and scalar multiplication.

This trait ensures that vector references can be used in arithmetic operations with owned vectors, other references, and vector views, enabling flexible composition of vector operations.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<RefT, V: Vector> VectorRef<V> for RefT
where RefT: VectorOpsByValue<V, V> + for<'a> VectorOpsByValue<&'a V, V> + for<'a> VectorOpsByValue<V::View<'a>, V> + for<'a, 'b> VectorOpsByValue<&'a V::View<'b>, V> + Mul<Scale<V::T>, Output = V>,