Context objects for managing device resources for vectors and matrices (e.g. device streams, threading pools, etc.).
This module provides context types that encapsulate information about where data is stored and computed (CPU, GPU, etc.). Different backends like nalgebra and faer may require different context implementations. The Context trait defines the interface that must be implemented.
Modules
Traits
- Context
- defines the current execution and allocation context of an operator / vector / matrix for example: