pub trait MatrixHost: Matrix<V: VectorHost> { }Expand description
A host matrix is a matrix type whose vector type is hosted on the CPU.
This trait extends Matrix to ensure the associated vector type implements VectorHost,
enabling direct CPU-side access to data. GPU matrices typically do not implement this trait.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".