ODE equations and traits.
This module defines the OdeEquations trait and specialized variants:
- OdeEquationsImplicit for implicit ODEs with mass matrices
- OdeEquationsImplicitSens for forward sensitivity equations
- OdeEquationsAdjoint for adjoint sensitivity equations
It also provides implementations:
- DiffSl for equations specified in the DiffSL domain-specific language
- SensEquations and AdjointEquations for sensitivity computations
All the test equations used in Diffsol’s test suite are also provided here.
Modules
Structs
- NoAug
- OdeEquations
Statistics - OdeSolver
Equations - This struct implements the ODE equation trait OdeEquations for a given right-hand side op, mass op, optional root op, and initial condition function.
Traits
- Augmented
OdeEquations - Augmented
OdeEquations Implicit - OdeEquations
- this is the trait that defines the ODE equations of the form
- OdeEquations
Adjoint - OdeEquations
Implicit - OdeEquations
Implicit Adjoint - OdeEquations
Implicit Sens - OdeEquations
Ref - this is the reference trait that defines the ODE equations of the form, this is used to define the ODE equations for a given lifetime. See OdeEquations for the main trait that defines the ODE equations.
- OdeEquations
Stoch