pub trait LinearOpTranspose: LinearOp {
// Required method
fn gemv_transpose_inplace(
&self,
_x: &Self::V,
_t: Self::T,
_beta: Self::T,
_y: &mut Self::V,
);
// Provided methods
fn call_transpose_inplace(&self, x: &Self::V, t: Self::T, y: &mut Self::V) { ... }
fn transpose_inplace(&self, t: Self::T, y: &mut Self::M) { ... }
fn _default_transpose_inplace(&self, t: Self::T, y: &mut Self::M) { ... }
fn transpose_sparsity(&self) -> Option<<Self::M as Matrix>::Sparsity> { ... }
}Required Methods
Provided Methods
Sourcefn call_transpose_inplace(&self, x: &Self::V, t: Self::T, y: &mut Self::V)
fn call_transpose_inplace(&self, x: &Self::V, t: Self::T, y: &mut Self::V)
Compute the transpose of the operator y = A(t)^T * x at a given state and time, the default implementation uses Self::gemv_transpose_inplace.
Sourcefn transpose_inplace(&self, t: Self::T, y: &mut Self::M)
fn transpose_inplace(&self, t: Self::T, y: &mut Self::M)
Compute the matrix representation of the transpose of the operator A(t)^T and store it in the matrix y.
The default implementation of this method computes the matrix using Self::gemv_transpose_inplace,
but it can be overriden for more efficient implementations.
Sourcefn _default_transpose_inplace(&self, t: Self::T, y: &mut Self::M)
fn _default_transpose_inplace(&self, t: Self::T, y: &mut Self::M)
Default implementation of the tranpose computation, see Self::transpose_inplace.